summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/kscoredialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:42:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:42:31 +0000
commit576eb4299a00bc053db35414406f46372a0f70f2 (patch)
tree4c030922d533821db464af566188e7d40cc8848c /libkdegames/highscore/kscoredialog.h
parent0718336b6017d1a4fc1d626544180a5a2a29ddec (diff)
downloadtdegames-576eb4299a00bc053db35414406f46372a0f70f2.tar.gz
tdegames-576eb4299a00bc053db35414406f46372a0f70f2.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1157643 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames/highscore/kscoredialog.h')
-rw-r--r--libkdegames/highscore/kscoredialog.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/libkdegames/highscore/kscoredialog.h b/libkdegames/highscore/kscoredialog.h
index 4d4a76db..50424caa 100644
--- a/libkdegames/highscore/kscoredialog.h
+++ b/libkdegames/highscore/kscoredialog.h
@@ -25,8 +25,8 @@ this software.
#ifndef KSCOREDIALOG_H
#define KSCOREDIALOG_H
-#include <qmap.h>
-#include <qptrlist.h>
+#include <tqmap.h>
+#include <tqptrlist.h>
#include <kdialogbase.h>
#include <kdemacros.h>
@@ -52,14 +52,14 @@ public:
Time = 1 << 28,
Score = 1 << 29 };
- typedef QMap<int, QString> FieldInfo;
+ typedef TQMap<int, TQString> FieldInfo;
/**
* @param fields Which fields should be listed.
* @param parent passed to parent QWidget constructor
* @param name passed to parent QWidget constructor
*/
- KScoreDialog(int fields, QWidget *parent=0, const char *name=0);
+ KScoreDialog(int fields, TQWidget *parent=0, const char *name=0);
~KScoreDialog();
@@ -67,13 +67,13 @@ public:
* @param group to use for reading/writing highscores from/to. By default
* the class will use "High Score"
*/
- void setConfigGroup(const QString &group);
+ void setConfigGroup(const TQString &group);
/**
* @param comment to add when showing high-scores.
* The comment is only used once.
*/
- void setComment(const QString &comment);
+ void setComment(const TQString &comment);
/**
* Define an extra FieldInfo entry.
@@ -81,7 +81,7 @@ public:
* @param header Header shown in the dialog for this field
* @param key used to store this field with.
*/
- void addField(int field, const QString &header, const QString &key);
+ void addField(int field, const TQString &header, const TQString &key);
/**
* Adds a new score to the list.
@@ -115,7 +115,7 @@ private:
void aboutToShow();
void setupDialog();
- void keyPressEvent( QKeyEvent *ev);
+ void keyPressEvent( TQKeyEvent *ev);
private:
class KScoreDialogPrivate;
@@ -52,14 +52,14 @@ public:
/**
* @param fields Which fields should be listed.
- * @param parent passed to parent QWidget constructor
- * @param name passed to parent QWidget constructor
+ * @param parent passed to parent TQWidget constructor
+ * @param name passed to parent TQWidget constructor
*/